@@ -30,12 +30,11 @@ logger = logging.getLogger(__name__)
 logger.info(f"Commence Logging. Saved to file: {LOG_FILEPATH}")
 
 # Must define logging config before remaining package imports
-from .lite import *
-from .api import * 
-from .planning import data_fetch, planner
-from .components import electrolyser, emissions, renewables
-from .defaults import *
-import argparse
+from nemglo.lite import *
+from nemglo.api import * 
+from nemglo.planning import data_fetch, planner
+from nemglo.components import electrolyser, emissions, renewables
+from nemglo.defaults import *
 
 from importlib.metadata import version
 try:
@@ -44,18 +43,4 @@ try:
 except:
     pass
 
-# Check if cache folder provided and valid filepath
-parser = argparse.ArgumentParser()
-parser.add_argument('--cache', '-c', type=str, \
-    help="provide a local filepath to a folder to be used for caching data")
-args = parser.parse_args()
 
-# Determine cache folder
-if (args.cache is None):
-    logging.info("Default data cache location is: {}.".format(DATA_CACHE.FILEPATH))
-elif (not os.path.exists(args.cache)):
-    logging.info("Default data cache location is: {}.".format(DATA_CACHE.FILEPATH))
-else:
-    DATA_CACHE.update_path(args.cache)
-    logging.info("Updated preffered data cache location to: {}."+ \
-        "Note, log files will save to default cache.".format(DATA_CACHE.FILEPATH))
